@@ -28,18 +28,8 @@ from congress import exception
 LOG = logging.getLogger(__name__)
 
 
-def d6service(name, keys, inbox, datapath, args):
-    return RowModel(name, keys, inbox=inbox, dataPath=datapath, **args)
-
-
 class RowModel(base.APIModel):
     """Model for handling API requests about Rows."""
-    def __init__(self, name, keys='', inbox=None, dataPath=None,
-                 policy_engine=None, datasource_mgr=None):
-        super(RowModel, self).__init__(name, keys, inbox=inbox,
-                                       dataPath=dataPath,
-                                       policy_engine=policy_engine,
-                                       datasource_mgr=datasource_mgr)
 
     # TODO(thinrichs): No rows have IDs right now.  Maybe eventually
     #   could make ID the hash of the row, but then might as well
@@ -56,6 +46,7 @@ class RowModel(base.APIModel):
     #          The matching item or None if item with id_ does not exist.
     #     """
 
+    # Note(thread-safety): blocking function
     def get_items(self, params, context=None):
         """Get items in model.
 
@@ -74,21 +65,35 @@ class RowModel(base.APIModel):
             gen_trace = True
 
         # Get the caller, it should be either policy or datasource
-        caller, source_id = api_utils.get_id_from_context(
-            context, self.datasource_mgr, self.engine)
-
+        # Note(thread-safety): blocking call
+        caller, source_id = api_utils.get_id_from_context(context)
+        # FIXME(threod-safety): in DSE2, the returned caller can be a
+        #   datasource name. But the datasource name may now refer to a new,
+        #   unrelated datasource. Causing the rest of this code to operate on
+        #   an unintended datasource.
+        #   It would have saved us if table_id was an UUID rather than a name,
+        #   but it appears that table_id is just another word for tablename.
+        #   Fix: check UUID of datasource before operating. Abort if mismatch
         table_id = context['table_id']
         try:
             args = {'table_id': table_id, 'source_id': source_id,
                     'trace': gen_trace}
-            result = self.invoke_rpc(caller, 'get_row_data', args)
+            if caller is base.ENGINE_SERVICE:
+                # allow extra time for row policy engine query
+                # Note(thread-safety): blocking call
+                result = self.invoke_rpc(
+                    caller, 'get_row_data', args,
+                    timeout=self.dse_long_timeout)
+            else:
+                # Note(thread-safety): blocking call
+                result = self.invoke_rpc(caller, 'get_row_data', args)
         except exception.CongressException as e:
             m = ("Error occurred while processing source_id '%s' for row "
                  "data of the table '%s'" % (source_id, table_id))
             LOG.exception(m)
             raise webservice.DataModelException.create(e)
 
-        if gen_trace and caller is self.engine:
+        if gen_trace and caller is base.ENGINE_SERVICE:
             # DSE2 returns lists instead of tuples, so correct that.
             results = [{'data': tuple(x['data'])} for x in result[0]]
             return {'results': results,
@@ -97,6 +102,7 @@ class RowModel(base.APIModel):
             result = [{'data': tuple(x['data'])} for x in result]
             return {'results': result}
 
+    # Note(thread-safety): blocking function
     def update_items(self, items, params, context=None):
         """Updates all data in a table.
 
@@ -111,23 +117,30 @@ class RowModel(base.APIModel):
             KeyError: table id doesn't exist
             DataModelException: any error occurs during replacing rows.
         """
-        LOG.info("update_items(context=%s)" % context)
-        caller, source_id = api_utils.get_id_from_context(context,
-                                                          self.datasource_mgr,
-                                                          self.engine)
+        LOG.info("update_items(context=%s)", context)
+        # Note(thread-safety): blocking call
+        caller, source_id = api_utils.get_id_from_context(context)
+        # FIXME(threod-safety): in DSE2, the returned caller can be a
+        #   datasource name. But the datasource name may now refer to a new,
+        #   unrelated datasource. Causing the rest of this code to operate on
+        #   an unintended datasource.
+        #   It would have saved us if table_id was an UUID rather than a name,
+        #   but it appears that table_id is just another word for tablename.
+        #   Fix: check UUID of datasource before operating. Abort if mismatch
         table_id = context['table_id']
         try:
             args = {'table_id': table_id, 'source_id': source_id,
                     'objs': items}
+            # Note(thread-safety): blocking call
             self.invoke_rpc(caller, 'update_entire_data', args)
         except exception.CongressException as e:
-            m = ("Error occurred while processing updating rows for "
-                 "source_id '%s' and table_id '%s'" % (source_id, table_id))
-            LOG.exception(m)
+            LOG.exception("Error occurred while processing updating rows "
+                          "for source_id '%s' and table_id '%s'",
+                          source_id, table_id)
             raise webservice.DataModelException.create(e)
-        LOG.info("finish update_items(context=%s)" % context)
-        LOG.debug("updated table %s with row items: %s" %
-                  (table_id, str(items)))
+        LOG.info("finish update_items(context=%s)", context)
+        LOG.debug("updated table %s with row items: %s",
+                  table_id, str(items))
 
     # TODO(thinrichs): It makes sense to sometimes allow users to create
     #  a new row for internal data sources.  But since we don't have
