@@ -27,19 +27,10 @@ from congress import exception
 LOG = logging.getLogger(__name__)
 
 
-def d6service(name, keys, inbox, datapath, args):
-    return TableModel(name, keys, inbox=inbox, dataPath=datapath, **args)
-
-
 class TableModel(base.APIModel):
     """Model for handling API requests about Tables."""
-    def __init__(self, name, keys='', inbox=None, dataPath=None,
-                 policy_engine=None, datasource_mgr=None):
-        super(TableModel, self).__init__(name, keys, inbox=inbox,
-                                         dataPath=dataPath,
-                                         policy_engine=policy_engine,
-                                         datasource_mgr=datasource_mgr)
 
+    # Note(thread-safety): blocking function
     def get_item(self, id_, params, context=None):
         """Retrieve item with id id_ from model.
 
@@ -52,13 +43,17 @@ class TableModel(base.APIModel):
         Returns:
              The matching item or None if item with id_ does not exist.
         """
-        caller, source_id = api_utils.get_id_from_context(
-            context,
-            self.datasource_mgr,
-            self.engine)
+        # Note(thread-safety): blocking call
+        caller, source_id = api_utils.get_id_from_context(context)
+        # FIXME(threod-safety): in DSE2, the returned caller can be a
+        #   datasource name. But the datasource name may now refer to a new,
+        #   unrelated datasource. Causing the rest of this code to operate on
+        #   an unintended datasource.
+        #   Fix: check UUID of datasource before operating. Abort if mismatch
 
         args = {'source_id': source_id, 'table_id': id_}
         try:
+            # Note(thread-safety): blocking call
             tablename = self.invoke_rpc(caller, 'get_tablename', args)
         except exception.CongressException as e:
             LOG.exception("Exception occurred while retrieving table %s"
@@ -70,6 +65,7 @@ class TableModel(base.APIModel):
 
         LOG.info('table id %s is not found in datasource %s', id_, source_id)
 
+    # Note(thread-safety): blocking function
     def get_items(self, params, context=None):
         """Get items in model.
 
@@ -84,12 +80,16 @@ class TableModel(base.APIModel):
         """
         LOG.info('get_items has context %s', context)
 
-        caller, source_id = api_utils.get_id_from_context(
-            context,
-            self.datasource_mgr,
-            self.engine)
+        # Note(thread-safety): blocking call
+        caller, source_id = api_utils.get_id_from_context(context)
+        # FIXME(threod-safety): in DSE2, the returned caller can be a
+        #   datasource name. But the datasource name may now refer to a new,
+        #   unrelated datasource. Causing the rest of this code to operate on
+        #   an unintended datasource.
+        #   Fix: check UUID of datasource before operating. Abort if mismatch
 
         try:
+            # Note(thread-safety): blocking call
             tablenames = self.invoke_rpc(caller, 'get_tablenames',
                                          {'source_id': source_id})
         except exception.CongressException as e:
