@@ -19,9 +19,6 @@ from __future__ import absolute_import
 
 import inspect
 
-import keystoneauth1.identity.v2 as ksidentity
-import keystoneauth1.session as kssession
-import keystoneclient.v2_0.client as ksclient
 import muranoclient.client
 from muranoclient.common import exceptions as murano_exceptions
 from oslo_log import log as logging
@@ -37,11 +34,6 @@ from congress import utils
 logger = logging.getLogger(__name__)
 
 
-def d6service(name, keys, inbox, datapath, args):
-    """This method is called by d6cage to create a dataservice instance."""
-    return MuranoDriver(name, keys, inbox, datapath, args)
-
-
 class MuranoDriver(datasource_driver.PollingDataSourceDriver,
                    datasource_driver.ExecutionDriver):
     OBJECTS = "objects"
@@ -55,27 +47,15 @@ class MuranoDriver(datasource_driver.PollingDataSourceDriver,
     UNUSED_ENV_PROPERTIES = ['id', 'tenant_id']
     APPS_TYPE_PREFIXES = ['io.murano.apps', 'io.murano.databases']
 
-    def __init__(self, name='', keys='', inbox=None, datapath=None, args=None):
-        super(MuranoDriver, self).__init__(name, keys, inbox, datapath, args)
+    def __init__(self, name='', args=None):
+        super(MuranoDriver, self).__init__(name, args=args)
         datasource_driver.ExecutionDriver.__init__(self)
         self.creds = args
-        logger.debug("Credentials = %s" % self.creds)
-        # TODO(ekcs): factor session creation out of individual driver
-        #   One single keystone session can be shared by all drivers
-        auth = ksidentity.Password(
-            auth_url=self.creds['auth_url'],
-            username=self.creds['username'],
-            password=self.creds['password'],
-            tenant_name=self.creds['tenant_name'])
-        session = kssession.Session(auth=auth)
-        keystone = ksclient.Client(**self.creds)
-        murano_endpoint = keystone.service_catalog.url_for(
-            service_type='application-catalog',
-            endpoint_type='publicURL')
-        logger.debug("murano_endpoint = %s" % murano_endpoint)
+        session = datasource_utils.get_keystone_session(self.creds)
         client_version = "1"
         self.murano_client = muranoclient.client.Client(
-            client_version, murano_endpoint, session=session)
+            client_version, session=session, endpoint_type='publicURL',
+            service_type='application-catalog')
         self.add_executable_client_methods(
             self.murano_client,
             'muranoclient.v1.')
@@ -122,8 +102,8 @@ class MuranoDriver(datasource_driver.PollingDataSourceDriver,
             self._translate_services(environments)
             self._translate_deployments(environments)
             self._translate_connected()
-        except murano_exceptions.HTTPException as e:
-            raise e
+        except murano_exceptions.HTTPException:
+            raise
 
     @classmethod
     def get_schema(cls):
@@ -527,4 +507,4 @@ class MuranoDriver(datasource_driver.PollingDataSourceDriver,
             action_name = positional_args[2]
             self._call_murano_action(env_id, obj_id, action_name)
         except Exception as e:
-            logger.exception(e.message)
+            logger.exception(str(e))
