@@ -18,6 +18,7 @@ from __future__ import division
 from __future__ import absolute_import
 
 import mock
+from oslo_config import cfg
 from oslo_log import log as logging
 
 from congress.datalog import base as datalog_base
@@ -32,7 +33,6 @@ from congress.policy_engines import agnostic
 from congress.tests import base
 from congress.tests import helper
 
-import congress.dse.d6cage
 
 LOG = logging.getLogger(__name__)
 
@@ -220,7 +220,8 @@ class TestRuntime(base.TestCase):
     @mock.patch.object(db_policy_rules, 'add_policy', side_effect=Exception())
     def test_persistent_create_policy_with_db_exception(self, mock_add):
         run = agnostic.Runtime()
-        with mock.patch.object(run, 'delete_policy') as mock_delete:
+        with mock.patch.object(run, 'delete_policy') as mock_delete,\
+                mock.patch.object(run, 'synchronize_policies') as mock_sync:
             policy_name = 'test_policy'
             self.assertRaises(exception.PolicyException,
                               run.persistent_create_policy,
@@ -231,7 +232,10 @@ class TestRuntime(base.TestCase):
                                              mock.ANY,
                                              'user',
                                              'nonrecursive')
-            mock_delete.assert_called_once_with(policy_name)
+            # mock_delete.assert_called_once_with(policy_name)
+            self.assertFalse(mock_delete.called)
+            self.assertFalse(mock_sync.called)
+            self.assertNotIn('test_policy', run.policy_names())
 
     def test_tablenames_theory_name(self):
         run = agnostic.Runtime()
@@ -437,7 +441,7 @@ class TestTriggerRegistry(base.TestCase):
         t3 = agnostic.Trigger('q', 'alice', lambda x: x)
         triggers = [t1, t2, t3]
         table_triggers = agnostic.TriggerRegistry.triggers_by_table(triggers)
-        self.assertTrue(len(table_triggers), 2)
+        self.assertEqual(2, len(table_triggers))
         self.assertEqual(set(table_triggers[('p', 'alice', None)]),
                          set([t1, t2]))
         self.assertEqual(set(table_triggers[('q', 'alice', None)]),
@@ -704,7 +708,7 @@ class TestMultipolicyRules(base.TestCase):
         run.insert('p(x) :- test1:q(x)', target='test2')
         actual = run.select('p(x)', target='test2')
         e = helper.db_equal('p(1) p(2)', actual)
-        self.assertTrue("Basic", e)
+        self.assertTrue(e, "Basic")
 
     def test_multi_external(self):
         """Test multiple rules that span multiple policies."""
@@ -719,7 +723,7 @@ class TestMultipolicyRules(base.TestCase):
         run.insert('p(2)', target='test3')
         actual = run.select('p(x)', target='test1')
         e = helper.db_equal(actual, 'p(1) p(2)')
-        self.assertTrue("Multiple external rules with multiple policies", e)
+        self.assertTrue(e, "Multiple external rules with multiple policies")
 
     def test_external_current(self):
         """Test ability to write rules that span multiple policies."""
@@ -734,7 +738,7 @@ class TestMultipolicyRules(base.TestCase):
         run.insert('r(2)', target='test2')
         actual = run.select('p(x)', target='test2')
         e = helper.db_equal(actual, 'p(1) p(2)')
-        self.assertTrue("Mixing external theories with current theory", e)
+        self.assertTrue(e, "Mixing external theories with current theory")
 
     def test_ignore_local(self):
         """Test ability to write rules that span multiple policies."""
@@ -751,7 +755,7 @@ class TestMultipolicyRules(base.TestCase):
         run.insert('r(3)', target='test2')
         actual = run.select('p(x)', target='test2')
         e = helper.db_equal(actual, 'p(1) p(2)')
-        self.assertTrue("Local table ignored", e)
+        self.assertTrue(e, "Local table ignored")
 
     def test_local(self):
         """Test ability to write rules that span multiple policies."""
@@ -765,7 +769,7 @@ class TestMultipolicyRules(base.TestCase):
         run.insert('q(2)', 'test2')
         actual = run.select('p(x)', target='test2')
         e = helper.db_equal(actual, 'p(2)')
-        self.assertTrue("Local table used", e)
+        self.assertTrue(e, "Local table used")
 
     def test_multiple_external(self):
         """Test ability to write rules that span multiple policies."""
@@ -828,32 +832,32 @@ class TestMultipolicyRules(base.TestCase):
         # policy in head of rule
         (permitted, errors) = run.insert('test2:p(x) :- q(x)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # policy in head of rule with update
         (permitted, errors) = run.insert('test2:p+(x) :- q(x)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # policy in head of rule with update
         (permitted, errors) = run.insert('test2:p-(x) :- q(x)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # policy in head of fact
         (permitted, errors) = run.insert('test2:p(1)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # policy in head of fact
         (permitted, errors) = run.insert('test2:p+(1)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # policy in head of fact
         (permitted, errors) = run.insert('test2:p-(1)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # recursion across policies
         run.insert('p(x) :- test2:q(x)', target='test1')
@@ -861,7 +865,7 @@ class TestMultipolicyRules(base.TestCase):
         (permit, errors) = run.insert('q(x) :- test1:p(x)', target='test2')
         self.assertFalse(permit, "Recursion across theories should fail")
         self.assertEqual(len(errors), 1)
-        self.assertTrue("Rules are recursive" in str(errors[0]))
+        self.assertIn("Rules are recursive", str(errors[0]))
 
     def test_multipolicy_action_errors(self):
         """Test errors arising from rules in action policies."""
@@ -872,12 +876,12 @@ class TestMultipolicyRules(base.TestCase):
         # policy in head of rule
         (permitted, errors) = run.insert('test2:p(x) :- q(x)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # policy in head of fact
         (permitted, errors) = run.insert('test2:p(1)', 'test1')
         self.assertFalse(permitted)
-        self.assertTrue("should not reference any policy" in str(errors[0]))
+        self.assertIn("should not reference any policy", str(errors[0]))
 
         # recursion across policies
         run.insert('p(x) :- test2:q(x)', target='test1')
@@ -885,7 +889,7 @@ class TestMultipolicyRules(base.TestCase):
         (permit, errors) = run.insert('q(x) :- test1:p(x)', target='test2')
         self.assertFalse(permit, "Recursion across theories should fail")
         self.assertEqual(len(errors), 1)
-        self.assertTrue("Rules are recursive" in str(errors[0]))
+        self.assertIn("Rules are recursive", str(errors[0]))
 
     def test_dependency_graph(self):
         """Test that dependency graph gets updated correctly."""
@@ -965,9 +969,9 @@ class TestMultipolicyRules(base.TestCase):
         rulestr = 'p(x,y) :- q(x,y)'
         rule = compile.parse1(rulestr)
         run.insert(rulestr, policy)
-        self.assertTrue(rule in run.policy_object(policy))
-        self.assertTrue(
-            rule.head.table.table in run.policy_object(policy).schema)
+        self.assertIn(rule, run.policy_object(policy))
+        self.assertIn(
+            rule.head.table.table, run.policy_object(policy).schema)
         run.insert(rulestr, policy)
         run.delete(rulestr, policy)
         self.assertFalse(rule in run.policy_object(policy))
@@ -1359,53 +1363,34 @@ class TestSimulate(base.TestCase):
 
 
 class TestActionExecution(base.TestCase):
-    class FakeCage(object):
-        def __init__(self, name):
-            self.name = name
 
-        def service_object(self, name):
-            if self.name == name:
-                return self
-            else:
-                return None
+    def setUp(self):
+        super(TestActionExecution, self).setUp()
+        self.run = agnostic.DseRuntime('test')
+        self.run.service_exists = mock.MagicMock()
+        self.run.service_exists.return_value = True
+        self.run._rpc = mock.MagicMock()
 
     def test_insert_rule_insert_data(self):
-        args = {}
-        args['d6cage'] = TestActionExecution.FakeCage('test')
-        args['rootdir'] = None
-        args['log_actions_only'] = True
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
-        run.create_policy('test')
-        run.debug_mode()
-        run.insert('execute[p(x)] :- q(x)')
-        self.assertEqual(len(run.logger.messages), 0, "Improper action logged")
-        run.insert('q(1)')
-        self.assertEqual(len(run.logger.messages), 1, "No action logged")
-        self.assertEqual(run.logger.messages[0], 'Executing test:p(1)')
+        self.run.create_policy('test')
+        self.run.debug_mode()
+        self.run.insert('execute[p(x)] :- q(x)')
+        self.assertEqual(len(self.run.logger.messages), 0,
+                         "Improper action logged")
+        self.run.insert('q(1)')
+        self.assertEqual(len(self.run.logger.messages), 1,
+                         "No action logged")
+        self.assertEqual(self.run.logger.messages[0], 'Executing test:p(1)')
 
         expected_args = ('test', 'p')
         expected_kwargs = {'args': {'positional': [1]}}
-        args, kwargs = run.request.call_args_list[0]
+        args, kwargs = self.run._rpc.call_args_list[0]
 
         self.assertEqual(expected_args, args)
         self.assertEqual(expected_kwargs, kwargs)
 
     def test_insert_data_insert_rule(self):
-        args = {}
-        args['d6cage'] = TestActionExecution.FakeCage('test')
-        args['rootdir'] = None
-        args['log_actions_only'] = True
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
+        run = self.run
         run.create_policy('test')
         run.debug_mode()
         run.insert('q(1)')
@@ -1416,22 +1401,12 @@ class TestActionExecution(base.TestCase):
 
         expected_args = ('test', 'p')
         expected_kwargs = {'args': {'positional': [1]}}
-        args, kwargs = run.request.call_args_list[0]
-
+        args, kwargs = run._rpc.call_args_list[0]
         self.assertEqual(expected_args, args)
         self.assertEqual(expected_kwargs, kwargs)
 
     def test_insert_data_insert_rule_delete_data(self):
-        args = {}
-        args['d6cage'] = TestActionExecution.FakeCage('test')
-        args['rootdir'] = None
-        args['log_actions_only'] = True
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
+        run = self.run
         run.create_policy('test')
         run.debug_mode()
         run.insert('q(1)')
@@ -1445,22 +1420,13 @@ class TestActionExecution(base.TestCase):
 
         expected_args = ('test', 'p')
         expected_kwargs = {'args': {'positional': [1]}}
-        args, kwargs = run.request.call_args_list[0]
+        args, kwargs = run._rpc.call_args_list[0]
 
         self.assertEqual(expected_args, args)
         self.assertEqual(expected_kwargs, kwargs)
 
     def test_insert_data_insert_rule_delete_rule(self):
-        args = {}
-        args['d6cage'] = TestActionExecution.FakeCage('test')
-        args['rootdir'] = None
-        args['log_actions_only'] = True
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
+        run = self.run
         run.create_policy('test')
         run.debug_mode()
         run.insert('q(1)')
@@ -1474,22 +1440,13 @@ class TestActionExecution(base.TestCase):
 
         expected_args = ('test', 'p')
         expected_kwargs = {'args': {'positional': [1]}}
-        args, kwargs = run.request.call_args_list[0]
+        args, kwargs = run._rpc.call_args_list[0]
 
         self.assertEqual(expected_args, args)
         self.assertEqual(expected_kwargs, kwargs)
 
     def test_insert_data_insert_rule_noop_insert(self):
-        args = {}
-        args['d6cage'] = TestActionExecution.FakeCage('test')
-        args['rootdir'] = None
-        args['log_actions_only'] = True
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
+        run = self.run
         run.create_policy('test')
         run.debug_mode()
         run.insert('q(1)')
@@ -1503,22 +1460,13 @@ class TestActionExecution(base.TestCase):
 
         expected_args = ('test', 'p')
         expected_kwargs = {'args': {'positional': [1]}}
-        args, kwargs = run.request.call_args_list[0]
+        args, kwargs = run._rpc.call_args_list[0]
 
         self.assertEqual(expected_args, args)
         self.assertEqual(expected_kwargs, kwargs)
 
     def test_disjunction(self):
-        args = {}
-        args['d6cage'] = TestActionExecution.FakeCage('test')
-        args['rootdir'] = None
-        args['log_actions_only'] = True
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
+        run = self.run
         run.create_policy('test')
         run.debug_mode()
         run.insert('execute[p(x)] :- q(x)')
@@ -1533,22 +1481,13 @@ class TestActionExecution(base.TestCase):
 
         expected_args = ('test', 'p')
         expected_kwargs = {'args': {'positional': [1]}}
-        args, kwargs = run.request.call_args_list[0]
+        args, kwargs = run._rpc.call_args_list[0]
 
         self.assertEqual(expected_args, args)
         self.assertEqual(expected_kwargs, kwargs)
 
     def test_multiple_instances(self):
-        args = {}
-        args['d6cage'] = TestActionExecution.FakeCage('test')
-        args['rootdir'] = None
-        args['log_actions_only'] = True
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
+        run = self.run
         run.create_policy('test')
         run.debug_mode()
         run.insert('q(1)')
@@ -1564,28 +1503,22 @@ class TestActionExecution(base.TestCase):
             [('test', 'p'), {'args': {'positional': [2]}}],
         ]
 
-        for args, kwargs in run.request.call_args_list:
-            self.assertTrue([args, kwargs] in expected_args_list)
+        for args, kwargs in run._rpc.call_args_list:
+            self.assertIn([args, kwargs], expected_args_list)
             expected_args_list.remove([args, kwargs])
 
     def test_disabled_execute_action(self):
-        args = {}
-        args['d6cage'] = None
-        args['rootdir'] = None
-        args['log_actions_only'] = False
-        run = agnostic.DseRuntime(
-            name='test', keys='', inbox=None, datapath=None, args=args)
-
-        run.request = mock.Mock()
-        run.request.return_value = 'mocked request'
-
+        cfg.CONF.set_override('enable_execute_action', False)
+        run = agnostic.DseRuntime('test')
+        run._rpc = mock.MagicMock()
+        run.service_exists = mock.MagicMock()
         service_name = 'test-service'
         action = 'non_executable_action'
         action_args = {'positional': ['p_arg1'],
                        'named': {'key1': 'value1'}}
 
         run.execute_action(service_name, action, action_args)
-        self.assertFalse(run.request.called)
+        self.assertFalse(run._rpc.called)
 
 
 class TestDisabledRules(base.SqlTestCase):
@@ -1618,16 +1551,7 @@ class TestDisabledRules(base.SqlTestCase):
         late-arriving schema when importing rules already in DB.
         This behavior is not necessary in persistent_insert.
         """
-        # FIXME(ekcs): test at Runtime level rather than DseRuntime level.
-        # temporarily test on DseRuntime because the persistence layer of
-        # Runtime depends on DseRuntime
-        cage = congress.dse.d6cage.d6Cage()
-        cage.loadModule("TestPolicy", helper.policy_module_path())
-        cage.createservice(name="policy", moduleName="TestPolicy",
-                           args={'d6cage': cage, 'rootdir': '',
-                                 'log_actions_only': True})
-        run = cage.services['policy']['object']
-
+        run = agnostic.Runtime()
         run.create_policy('data', kind=datalog_base.DATASOURCE_POLICY_TYPE)
         run.persistent_create_policy('policy')
         obj = run.policy_object('policy')
@@ -1666,7 +1590,7 @@ class TestDisabledRules(base.SqlTestCase):
         permitted, errors = run.insert('p(x) :- q(id=x)')
         self.assertFalse(permitted)
         errstring = " ".join(str(x) for x in errors)
-        self.assertTrue("column name id does not exist" in errstring)
+        self.assertIn("column name id does not exist", errstring)
         self.assertEqual(len(run.error_events), 0)
         self.assertEqual(len(run.disabled_events), 0)
         self.assertEqual(len(obj.content()), 0)
@@ -1759,7 +1683,7 @@ class TestDisabledRules(base.SqlTestCase):
         permitted, errors = run.delete('p(x) :- q(id=x)')
         self.assertFalse(permitted)
         errstring = " ".join(str(x) for x in errors)
-        self.assertTrue("column name id does not exist" in errstring)
+        self.assertIn("column name id does not exist", errstring)
         self.assertEqual(len(run.error_events), 0)
         self.assertEqual(len(run.disabled_events), 0)
         self.assertEqual(len(obj.content()), 0)
@@ -1784,7 +1708,7 @@ class TestDisabledRules(base.SqlTestCase):
             run.set_schema('test', schema)
             self.fail("Error not thrown on unknown policy")
         except exception.CongressException as e:
-            self.assertTrue("not been created" in str(e))
+            self.assertIn("not been created", str(e))
 
     def test_disallow_schema_change(self):
         # Ensures that cannot change schema once it is set.
@@ -1798,7 +1722,7 @@ class TestDisabledRules(base.SqlTestCase):
             run.set_schema('test', schema)
             self.fail("Error not thrown on schema change")
         except exception.CongressException as e:
-            self.assertTrue("Schema for test already set" in str(e))
+            self.assertIn("Schema for test already set", str(e))
 
     def test_insert_without_datasource_policy(self):
         run = agnostic.Runtime()
